summaryrefslogtreecommitdiffstats
path: root/qt/qextscintillalexerperl.h
diff options
context:
space:
mode:
Diffstat (limited to 'qt/qextscintillalexerperl.h')
-rw-r--r--qt/qextscintillalexerperl.h39
1 files changed, 20 insertions, 19 deletions
diff --git a/qt/qextscintillalexerperl.h b/qt/qextscintillalexerperl.h
index 0beb75a..f6e52e1 100644
--- a/qt/qextscintillalexerperl.h
+++ b/qt/qextscintillalexerperl.h
@@ -3,38 +3,39 @@
// Copyright (c) 2006
// Riverbank Computing Limited <info@riverbankcomputing.co.uk>
//
-// This file is part of QScintilla.
+// This file is part of TQScintilla.
//
-// This copy of QScintilla is free software; you can redistribute it and/or
+// This copy of TQScintilla is free software; you can redistribute it and/or
// modify it under the terms of the GNU General Public License as published by
// the Free Software Foundation; either version 2, or (at your option) any
// later version.
//
-// QScintilla is supplied in the hope that it will be useful, but WITHOUT ANY
+// TQScintilla is supplied in the hope that it will be useful, but WITHOUT ANY
// WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
// FOR A PARTICULAR PURPOSE. See the GNU General Public License for more
// details.
//
// You should have received a copy of the GNU General Public License along with
-// QScintilla; see the file LICENSE. If not, write to the Free Software
+// TQScintilla; see the file LICENSE. If not, write to the Free Software
// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
-#ifndef QEXTSCINTILLALEXERPERL_H
-#define QEXTSCINTILLALEXERPERL_H
+#ifndef TQEXTSCINTILLALEXERPERL_H
+#define TQEXTSCINTILLALEXERPERL_H
-#include <qobject.h>
+#include <tqobject.h>
-#include <qextscintillaglobal.h>
-#include <qextscintillalexer.h>
+#include <tqextscintillaglobal.h>
+#include <tqextscintillalexer.h>
//! \brief The QextScintillaLexerPerl class encapsulates the Scintilla Perl
//! lexer.
-class QEXTSCINTILLA_EXPORT QextScintillaLexerPerl : public QextScintillaLexer
+class TQEXTSCINTILLA_EXPORT QextScintillaLexerPerl : public QextScintillaLexer
{
Q_OBJECT
+ TQ_OBJECT
public:
//! This enum defines the meanings of the different styles used by the
@@ -130,7 +131,7 @@ public:
//! Construct a QextScintillaLexerPerl with parent \a parent and name
//! \a name. \a parent is typically the QextScintilla instance.
- QextScintillaLexerPerl(QObject *parent = 0,const char *name = 0);
+ QextScintillaLexerPerl(TQObject *parent = 0,const char *name = 0);
//! Destroys the QextScintillaLexerPerl instance.
virtual ~QextScintillaLexerPerl();
@@ -152,28 +153,28 @@ public:
//! \a style.
//!
//! \sa paper()
- QColor color(int style) const;
+ TQColor color(int style) const;
//! Returns the end-of-line fill for style number \a style.
bool eolFill(int style) const;
//! Returns the font for style number \a style.
- QFont font(int style) const;
+ TQFont font(int style) const;
//! Returns the set of keywords for the keyword set \a set recognised
//! by the lexer as a space separated string.
const char *keywords(int set) const;
//! Returns the descriptive name for style number \a style. If the
//! style is invalid for this language then QString::null is returned.
//! This is intended to be used in user preference dialogs.
- QString description(int style) const;
+ TQString description(int style) const;
//! Returns the background colour of the text for style number
//! \a style.
//!
//! \sa color()
- QColor paper(int style) const;
+ TQColor paper(int style) const;
//! Causes all properties to be refreshed by emitting the
//! propertyChanged() signal as required.
@@ -207,13 +208,13 @@ protected:
//! (which has a trailing '/') should be used as a prefix to the key of
//! each setting. TRUE is returned if there is no error.
//!
- bool readProperties(QSettings &qs,const QString &prefix);
+ bool readProperties(TQSettings &qs,const TQString &prefix);
//! The lexer's properties are written to the settings \a qs.
//! \a prefix (which has a trailing '/') should be used as a prefix to
//! the key of each setting. TRUE is returned if there is no error.
//!
- bool writeProperties(QSettings &qs,const QString &prefix) const;
+ bool writeProperties(TQSettings &qs,const TQString &prefix) const;
private:
void setCommentProp();
@@ -222,7 +223,7 @@ private:
bool fold_comments;
bool fold_compact;
-#if defined(Q_DISABLE_COPY)
+#if defined(TQ_DISABLE_COPY)
QextScintillaLexerPerl(const QextScintillaLexerPerl &);
QextScintillaLexerPerl &operator=(const QextScintillaLexerPerl &);
#endif
@@ -152,28 +153,28 @@ public:
const char *keywords(int set) const;
//! Returns the descriptive name for style number \a style. If the
- //! style is invalid for this language then QString::null is returned.
+ //! style is invalid for this language then TQString() is returned.
//! This is intended to be used in user preference dialogs.